@@ -15,7 +15,9 @@ import sys
 import os
 
 base = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-site_packages = os.path.join(base, "lib", "python%s" % sys.version[:3], "site-packages")
+site_packages = os.path.join(
+    base, "lib", "python%s" % sys.version[:3], "site-packages"
+)
 prev_sys_path = list(sys.path)
 import site
 
